@@ -491,6 +491,10 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 								CPEs: []string{
 									"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
 								},
+								Package: search.CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "3.7.5",
+								},
 							},
 							Found: search.CPEResult{
 								VulnerabilityID:   "CVE-2014-fake-3",
@@ -526,6 +530,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							SearchedBy: map[string]any{
 								"language":  "ruby",
 								"namespace": "github:language:ruby",
+								"package":   map[string]string{"name": "activerecord", "version": "3.7.5"},
 							},
 							Found: map[string]any{
 								"versionConstraint": "< 3.7.6 (unknown)",
@@ -579,6 +584,20 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 					},
 					Package: activerecordPkg,
 					Details: match.Details{
+						{
+							Type: match.ExactDirectMatch,
+							SearchedBy: map[string]any{
+								"language":  "ruby",
+								"namespace": "github:language:ruby",
+								"package":   map[string]string{"name": "activerecord", "version": "3.7.5"},
+							},
+							Found: map[string]any{
+								"versionConstraint": "< 3.7.6 (unknown)",
+								"vulnerabilityID":   "GHSA-2014-fake-3",
+							},
+							Matcher:    "ruby-gem-matcher",
+							Confidence: 1,
+						},
 						{
 							Type: match.CPEMatch,
 							SearchedBy: search.CPEParameters{
@@ -586,6 +605,10 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 								CPEs: []string{
 									"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
 								},
+								Package: search.CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "3.7.5",
+								},
 							},
 							Found: search.CPEResult{
 								VulnerabilityID:   "CVE-2014-fake-3",
@@ -597,19 +620,6 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							Matcher:    "ruby-gem-matcher",
 							Confidence: 0.9,
 						},
-						{
-							Type: match.ExactDirectMatch,
-							SearchedBy: map[string]any{
-								"language":  "ruby",
-								"namespace": "github:language:ruby",
-							},
-							Found: map[string]any{
-								"versionConstraint": "< 3.7.6 (unknown)",
-								"vulnerabilityID":   "GHSA-2014-fake-3",
-							},
-							Matcher:    "ruby-gem-matcher",
-							Confidence: 1,
-						},
 					},
 				},
 			),
@@ -661,6 +671,10 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 								CPEs: []string{
 									"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
 								},
+								Package: search.CPEPackageParameter{
+									Name:    "activerecord",
+									Version: "3.7.5",
+								},
 							},
 							Found: search.CPEResult{
 								VulnerabilityID:   "CVE-2014-fake-3",
@@ -731,6 +745,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 								SearchedBy: map[string]any{
 									"language":  "ruby",
 									"namespace": "github:language:ruby",
+									"package":   map[string]string{"name": "activerecord", "version": "3.7.5"},
 								},
 								Found: map[string]any{
 									"versionConstraint": "< 3.7.6 (unknown)",
@@ -788,6 +803,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							SearchedBy: map[string]any{
 								"language":  "ruby",
 								"namespace": "github:language:ruby",
+								"package":   map[string]string{"name": "activerecord", "version": "3.7.5"},
 							},
 							Found: map[string]any{
 								"versionConstraint": "< 3.7.6 (unknown)",
@@ -826,6 +842,10 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 									CPEs: []string{
 										"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
 									},
+									Package: search.CPEPackageParameter{
+										Name:    "activerecord",
+										Version: "3.7.5",
+									},
 								},
 								Found: search.CPEResult{
 									VulnerabilityID:   "CVE-2014-fake-3",
