@@ -25,8 +25,6 @@ func (r *Handler) RespondsTo(event partybus.Event) bool {
 	switch event.Type {
 	case grypeEvent.VulnerabilityScanningStarted,
 		grypeEvent.UpdateVulnerabilityDatabase,
-		grypeEvent.AttestationVerified,
-		grypeEvent.AttestationVerificationSkipped,
 		grypeEvent.DatabaseDiffingStarted:
 		return true
 	default:
@@ -40,10 +38,6 @@ func (r *Handler) Handle(ctx context.Context, fr *frame.Frame, event partybus.Ev
 		return r.VulnerabilityScanningStartedHandler(ctx, fr, event, wg)
 	case grypeEvent.UpdateVulnerabilityDatabase:
 		return r.UpdateVulnerabilityDatabaseHandler(ctx, fr, event, wg)
-	case grypeEvent.AttestationVerified:
-		return r.VerifyAttestationSignature(ctx, fr, event, wg)
-	case grypeEvent.AttestationVerificationSkipped:
-		return r.SkippedAttestationVerification(ctx, fr, event, wg)
 	case grypeEvent.DatabaseDiffingStarted:
 		return r.DatabaseDiffingStartedHandler(ctx, fr, event, wg)
 	default:
